web-payments-connector
======================

This project is a fork from django-payments.
Because the whole structure changes in a
backward incompatible manner, I forked.

Features:
* small framework agnostic connector
* more flexible
  * shipping and billing address
  * addresses generated by function; this allows reuse of other framework components
  * dynamic url generation
* new not so generic name (web_payments)
* better test facilities
* can hold bitcoins and weak currencies
* more security features (safe xml parsing, hidden credentials)
* framework independent translation
* better documented API (source code)

TODO:
* porting backends
* documentation for version 2.1
* Maybe: safe token cache facility
* django-oscar integration

Note: I use semantic versioning.
